@@ -15,15 +15,14 @@ if parent_dir not in sys.path:
     sys.path.append(parent_dir)
 
 # Import from parent modules
-from webapp import DEFAULT_YAML_FPATH, read_config, DEFAULT_YAML
-from utils import hide_webapp_sidebar_item, load_llm, check_manage_access
+from OnPrem import DEFAULT_YAML_FPATH, read_config, DEFAULT_YAML
+from utils import load_llm, check_manage_access
 
 def main():
     """
     Manage page for configuring the application and ingesting documents
     """
-    # Hide webapp sidebar item
-    hide_webapp_sidebar_item()
+    # No need to hide webapp sidebar item anymore
     
     # Check if manage page should be accessible
     if not check_manage_access():
@@ -95,6 +94,12 @@ def main():
         - PowerPoint (`.pptx`): Microsoft PowerPoint presentations
         - Markdown (`.md`): Markdown text files
         - JSON (`.json`): JavaScript Object Notation files
+        
+        Advanced options under "Ingestion Options" allow you to:
+        - Customize chunk size and overlap
+        - Preserve paragraph structure during chunking
+        - Control batch processing size
+        - Clear existing documents before ingestion
         """)
         
         # Get config to extract rag_source_path
@@ -111,92 +116,86 @@ def main():
             rag_source_path = rag_source_path.format(webapp_dir=U.get_webapp_dir())
             os.makedirs(rag_source_path, exist_ok=True)
             
-            st.info(f"Documents root directory: {rag_source_path}")
             
             # Get store type from config
             store_type = cfg.get("llm", {}).get("store_type", "dense")
             
-            # Create tabs for different upload types
-            upload_tab1, upload_tab2 = st.tabs(["Upload Individual Files", "Upload ZIP Archive"])
+            # Initialize placeholders for file upload UI (will be set later)
+            uploaded_files = None
+            uploaded_zip = None
             
-            with upload_tab1:
-                # Using placeholder for file upload UI (moved to bottom)
-                uploaded_files = None
-                
-                # Display preview of selected files, if any
-                if uploaded_files:
-                    # Show preview of selected files
-                    with st.expander(f"Selected {len(uploaded_files)} file(s) for upload", expanded=False):
-                        file_info = []
-                        total_size = 0
+            # Display preview of selected files based on upload type
+            if uploaded_files:
+                # Show preview of selected files
+                with st.expander(f"Selected {len(uploaded_files)} file(s) for upload", expanded=False):
+                    file_info = []
+                    total_size = 0
+                    
+                    # Collect file information
+                    for f in uploaded_files:
+                        size_kb = f.size / 1024
+                        total_size += size_kb
+                        file_info.append({
+                            "name": f.name, 
+                            "type": f.type if hasattr(f, 'type') and f.type else "Unknown",
+                            "size": f"{size_kb:.1f} KB"
+                        })
+                    
+                    # Display files in a table
+                    st.write("Files to upload:")
+                    col1, col2, col3 = st.columns([3, 2, 1])
+                    with col1:
+                        st.write("**Filename**")
+                    with col2:
+                        st.write("**Type**")
+                    with col3:
+                        st.write("**Size**")
                         
-                        # Collect file information
-                        for f in uploaded_files:
-                            size_kb = f.size / 1024
-                            total_size += size_kb
-                            file_info.append({
-                                "name": f.name, 
-                                "type": f.type if hasattr(f, 'type') and f.type else "Unknown",
-                                "size": f"{size_kb:.1f} KB"
-                            })
-                        
-                        # Display files in a table
-                        st.write("Files to upload:")
+                    for file in file_info:
                         col1, col2, col3 = st.columns([3, 2, 1])
                         with col1:
-                            st.write("**Filename**")
+                            st.write(file["name"])
                         with col2:
-                            st.write("**Type**")
+                            st.write(file["type"])
                         with col3:
-                            st.write("**Size**")
+                            st.write(file["size"])
                             
-                        for file in file_info:
-                            col1, col2, col3 = st.columns([3, 2, 1])
-                            with col1:
-                                st.write(file["name"])
-                            with col2:
-                                st.write(file["type"])
-                            with col3:
-                                st.write(file["size"])
-                                
-                        st.info(f"Total size: {total_size/1024:.2f} MB")
+                    st.info(f"Total size: {total_size/1024:.2f} MB")
             
-            with upload_tab2:
-                # Using placeholder for file upload UI (moved to bottom)
-                uploaded_zip = None
+            elif uploaded_zip:
+                # Show ZIP file details
+                size_mb = uploaded_zip.size / (1024 * 1024)
+                st.info(f"Selected ZIP file: {uploaded_zip.name} ({size_mb:.2f} MB)")
                 
-                # Display preview of selected files, if any
-                if uploaded_zip:
-                    # Show ZIP file details
-                    size_mb = uploaded_zip.size / (1024 * 1024)
-                    st.info(f"Selected ZIP file: {uploaded_zip.name} ({size_mb:.2f} MB)")
-                    
-                    # Show preview of ZIP contents if possible
-                    try:
-                        with tempfile.TemporaryDirectory() as temp_dir:
-                            # Save the uploaded zip file to a temporary file
-                            temp_zip_path = os.path.join(temp_dir, "preview.zip")
-                            with open(temp_zip_path, "wb") as f:
-                                f.write(uploaded_zip.getvalue())
+                # Show preview of ZIP contents if possible
+                try:
+                    with tempfile.TemporaryDirectory() as temp_dir:
+                        # Save the uploaded zip file to a temporary file
+                        temp_zip_path = os.path.join(temp_dir, "preview.zip")
+                        with open(temp_zip_path, "wb") as f:
+                            f.write(uploaded_zip.getvalue())
+                        
+                        # Read ZIP contents without extracting
+                        with zipfile.ZipFile(temp_zip_path, 'r') as zip_ref:
+                            zip_files = zip_ref.namelist()
                             
-                            # Read ZIP contents without extracting
-                            with zipfile.ZipFile(temp_zip_path, 'r') as zip_ref:
-                                zip_files = zip_ref.namelist()
+                            # Display file count and preview in expander
+                            with st.expander(f"ZIP archive contains {len(zip_files)} file(s)", expanded=False):
+                                # Show only first 50 files to avoid UI overload
+                                preview_files = zip_files[:50]
+                                for file in preview_files:
+                                    # Skip directories
+                                    if not file.endswith('/'):
+                                        st.write(f"📄 {file}")
                                 
-                                # Display file count and preview in expander
-                                with st.expander(f"ZIP archive contains {len(zip_files)} file(s)", expanded=False):
-                                    # Show only first 50 files to avoid UI overload
-                                    preview_files = zip_files[:50]
-                                    for file in preview_files:
-                                        # Skip directories
-                                        if not file.endswith('/'):
-                                            st.write(f"📄 {file}")
-                                    
-                                    if len(zip_files) > 50:
-                                        st.write(f"*...and {len(zip_files) - 50} more files*")
-                    except Exception as e:
-                        st.warning(f"Unable to preview ZIP contents: {str(e)}")
+                                if len(zip_files) > 50:
+                                    st.write(f"*...and {len(zip_files) - 50} more files*")
+                except Exception as e:
+                    st.warning(f"Unable to preview ZIP contents: {str(e)}")
             
+            st.markdown('**STEP 1: Select or create a folder in which your uploaded documents will be stored.**')
+            st.markdown('*Folders are used to organize your uploaded documents.*')
+
             # Subfolder selection - require using subfolders
             subfolder_option = st.radio(
                 "Upload documents to:",
@@ -236,6 +235,9 @@ def main():
             else:
                 st.error("Please select an existing subfolder or create a new one above before uploading.")
             
+
+            st.markdown('**STEP 2: [OPTIONAL] Customize document processing settings.**')
+            st.markdown('*We recommend leaving the defaults for most users.*')
             # Place all ingestion options in an expander
             with st.expander("Ingestion Options", expanded=False):
                 st.subheader("Document Processing Settings")
@@ -255,6 +257,13 @@ def main():
                                                   value=50,
                                                   help="Character overlap between chunks")
                 
+                # Paragraph preservation option
+                preserve_paragraphs = st.checkbox(
+                    "Preserve paragraphs during chunking", 
+                    value=False,
+                    help="If checked, documents will be chunked at paragraph boundaries. If a paragraph exceeds the chunk size, it will be split. If unchecked, small paragraphs will be combined into a single chunk until the chunk size is reached. We recommend you leave this off unless you are performing a **Document Analysis** that would benefit from retaining paragraphs."
+                )
+                
                 # Display store type (read-only)
                 st.info(f"Using store type from configuration: {store_type}")
                 
@@ -385,32 +394,17 @@ def main():
                                 if st.button("Confirm Delete"):
                                     try:
                                         # Remove documents from vectorstore
-                                        try:
-                                            st.text(f"Removing documents from '{current_folder}' in vectorstore...")
+                                        st.text(f"Removing documents from '{current_folder}' in vectorstore...")
                                             
-                                            # Get all files in the folder - these are the sources to remove
-                                            file_paths = []
-                                            for root, dirs, files in os.walk(folder_path):
-                                                for file in files:
-                                                    file_path = os.path.join(root, file)
-                                                    file_paths.append(file_path)
-                                            
-                                            # Load LLM and get vectorstore
-                                            llm = load_llm()
-                                            vectorstore = llm.load_vectorstore()
-                                            
-                                            # Remove each document source
-                                            for source_path in file_paths:
-                                                try:
-                                                    print(os.path.abspath(source_path))
-                                                    vectorstore.remove_source(os.path.abspath(source_path))
-                                                except Exception as e:
-                                                    st.warning(f"Error removing {os.path.basename(source_path)}: {str(e)}")
-                                            
-                                            st.success(f"Documents from '{current_folder}' removed from vectorstore.")
-                                        except Exception as e:
-                                            st.warning(f"Error removing documents from vectorstore: {str(e)}")
                                             
+                                        # Load LLM and get vectorstore
+                                        llm = load_llm()
+                                        vectorstore = llm.load_vectorstore()
+                                       
+                                        # Delete documents from vectorstore
+                                        normed_folder_path = os.path.normpath(folder_path).replace('\\', '/')
+                                        num_records_deleted = vectorstore.remove_source(normed_folder_path)
+                                        st.text(f'{num_records_deleted} records deleted from vectorstore.')
                                         
                                         # Delete the folder
                                         shutil.rmtree(folder_path)
@@ -419,9 +413,14 @@ def main():
                                         # Reset state and refresh
                                         st.session_state.delete_state = {"stage": 0, "folder": None}
                                         
-                                        # Add small delay to ensure message is shown before refresh
+                                        # Create a countdown before refresh
                                         import time
-                                        time.sleep(5)
+                                        countdown_seconds = 5
+                                        countdown_placeholder = st.empty()
+                                        for i in range(countdown_seconds, 0, -1):
+                                            countdown_placeholder.info(f"Refreshing in {i} seconds...")
+                                            time.sleep(1)
+                                        countdown_placeholder.info("Refreshing now...")
                                         st.rerun()
                                     except Exception as e:
                                         st.error(f"Error deleting folder: {str(e)}")
@@ -432,13 +431,16 @@ def main():
             
             # Ingest button is placed outside all expanders for visibility
 
+
+            st.markdown('**STEP 3: Select and upload files for ingestion into the document store.**')
+            st.info(f"Documents store location: {rag_source_path}")
             # Create columns to place file uploader next to the ingest button
             col1, col2 = st.columns([3, 1])
             
             with col1:
                 # Create a radio selector to choose file upload type
                 upload_type = st.radio(
-                    "Upload type:",
+                    "What would you like to upload?",
                     ["Individual files", "ZIP archive"],
                     horizontal=True
                 )
@@ -529,12 +531,20 @@ def main():
                             llm = load_llm()
                             
                             # Ingest documents from the target folder
-                            result = llm.ingest(
-                                source_directory=target_folder,
-                                chunk_size=chunk_size,
-                                chunk_overlap=chunk_overlap,
-                                batch_size=batch_size
-                            )
+                            # Set n_proc=1 on Windows to avoid multiprocessing issues with Streamlit
+                            kwargs = {
+                                "source_directory": target_folder,
+                                "chunk_size": chunk_size,
+                                "chunk_overlap": chunk_overlap,
+                                "batch_size": batch_size,
+                                "preserve_paragraphs": preserve_paragraphs
+                            }
+                            # Add n_proc=1 on Windows to avoid multiprocessing stalls
+                            if os.name == 'nt':  # Windows
+                                kwargs["n_proc"] = 1
+                                st.text("Windows detected: Using single process mode for document ingestion")
+                            
+                            result = llm.ingest(**kwargs)
                             
                             # Show success message with folder information
                             folder_display = os.path.basename(target_folder) if target_folder != rag_source_path else "main folder"
@@ -550,4 +560,11 @@ def main():
                     
 
 if __name__ == "__main__":
+    # Set page to wide mode when run directly
+    st.set_page_config(
+        page_title="Manage", 
+        page_icon="⚙️", 
+        layout="wide",
+        initial_sidebar_state="expanded"
+    )
     main()
